/*
 * This file is part of the KubeVirt project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Copyright 2018 Red Hat, Inc.
 *
 */

package main

import (
	klog "kubevirt.io/client-go/log"

	"kubevirt.io/kubevirt/pkg/service"
	virt_api "kubevirt.io/kubevirt/pkg/virt-api"
)

func main() {
	klog.InitializeLogging("virt-api")

	app := virt_api.NewVirtApi()
	service.Setup(app)
	app.Execute()
}
